# CohortWindow

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**patient_metadata_start_filter_enabled** | **bool** |  | [optional] 
**patient_metadata_end_filter_enabled** | **bool** |  | [optional] 
**cohort_logic** | **str** |  | [optional] 
**cohort_display_logic** | **str** |  | [optional] 
**outcome_logic** | **str** |  | [optional] 
**intervention_logic** | **str** |  | [optional] 
**period_definitions** | [**list[PeriodDefinition]**](PeriodDefinition.md) |  | 
**outcome_type** | **str** |  | 
**aggregation_type** | **str** |  | [optional] 
**aggregation_column** | **str** |  | [optional] 
**cohort_filters** | [**list[CohortFilter]**](CohortFilter.md) |  | [optional] 
**outcome_aggregated_value** | **float** |  | [optional] 
**outcome_list_query** | **str** |  | [optional] 
**outcome_count_query** | **str** |  | [optional] 
**intervention_list_query** | **str** |  | [optional] 
**intervention_count_query** | **str** |  | [optional] 
**cohort_list_query** | **str** |  | [optional] 
**cohort_count_query** | **str** |  | [optional] 
**outcome_count** | **float** |  | [optional] 
**intervention_count** | **float** |  | [optional] 
**cohort_count** | **float** |  | [optional] 
**geographic_counts** | [**GeographicCounts**](GeographicCounts.md) |  | [optional] 
**geographic_queries** | [**GeographicQueries**](GeographicQueries.md) |  | [optional] 
**dataset_ids** | **list[str]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

